import React from 'react';
import { Mail, Twitter, Instagram, Bot, ExternalLink } from 'lucide-react';
import { Link } from 'react-router-dom';

const Footer: React.FC = () => {
  return (
    <footer className="relative bg-gradient-to-br from-gray-900 via-gray-800 to-gray-900 py-16">
      <div className="absolute inset-0 bg-[radial-gradient(circle_at_30%_50%,rgba(59,130,246,0.1),transparent_50%)]"></div>
      <div className="container mx-auto px-4 md:px-6 lg:px-8">
        <div className="relative max-w-6xl mx-auto">
          <div className="grid md:grid-cols-4 gap-12 mb-12">
            <div className="col-span-2">
              <Link to="/" className="flex items-center mb-6 group" aria-label="ZenTalk Home">
                <div className="relative w-10 h-10 mr-2">
                  <div className="absolute inset-0 bg-gradient-to-r from-blue-500/20 to-teal-500/20 rounded-lg blur group-hover:blur-md transition-all duration-500"></div>
                  <div className="absolute inset-0 bg-gradient-to-br from-blue-500 to-teal-500 rounded-lg opacity-90"></div>
                  <div className="absolute inset-0 flex items-center justify-center">
                    <div className="w-6 h-[2px] bg-white/25 rounded-full absolute transform translate-y-[6px]"></div>
                    <div className="w-6 h-[2px] bg-white/50 rounded-full absolute transform translate-y-[2px]"></div>
                    <div className="w-6 h-[2px] bg-white/75 rounded-full absolute transform translate-y-[-2px]"></div>
                    <div className="w-6 h-[2px] bg-white rounded-full absolute transform translate-y-[-6px]"></div>
                  </div>
                </div>
                <span className="text-2xl font-bold bg-gradient-to-r from-blue-400 to-teal-400 bg-clip-text text-transparent">
                  ZenTalk
                </span>
              </Link>
              <p className="text-gray-300 max-w-md leading-relaxed mb-6">
                Transforming communication through mindful AI solutions. Creating harmonious interactions between businesses and customers, one conversation at a time.
              </p>
              <div className="flex items-center space-x-4">
                <a 
                  href="mailto:hello@zentalk.ai" 
                  aria-label="Send email"
                  className="p-2 bg-gray-800 rounded-lg hover:bg-blue-600 transition-all duration-300 group border border-blue-500/30 hover:border-blue-500 hover:shadow-[0_0_15px_rgba(59,130,246,0.5)]"
                >
                  <Mail className="h-5 w-5 text-gray-300 group-hover:text-white transition-colors" />
                </a>
                <a 
                  href="#" 
                  aria-label="Follow us on Twitter"
                  className="p-2 bg-gray-800 rounded-lg hover:bg-blue-500 transition-all duration-300 group border border-blue-500/30 hover:border-blue-500 hover:shadow-[0_0_15px_rgba(59,130,246,0.5)]"
                >
                  <Twitter className="h-5 w-5 text-gray-400 group-hover:text-white transition-colors" />
                </a>
                <a 
                  href="#" 
                  aria-label="Follow us on Instagram"
                  className="p-2 bg-gray-800 rounded-lg hover:bg-blue-500 transition-all duration-300 group border border-blue-500/30 hover:border-blue-500 hover:shadow-[0_0_15px_rgba(59,130,246,0.5)]"
                >
                  <Instagram className="h-5 w-5 text-gray-400 group-hover:text-white transition-colors" />
                </a>
              </div>
            </div>
            
            <div>
              <h3 className="text-white font-semibold mb-4" id="solutions-heading">Solutions</h3>
              <ul className="space-y-3" aria-labelledby="solutions-heading">
                <li>
                  <Link to="/ai-automation" className="text-gray-400 hover:text-blue-400 transition-colors flex items-center group">
                    AI Automation
                    <ExternalLink className="h-4 w-4 ml-1 opacity-0 group-hover:opacity-100 transition-opacity" />
                  </Link>
                </li>
                <li>
                  <Link to="/smart-chatbots" className="text-gray-400 hover:text-blue-400 transition-colors flex items-center group">
                    Smart Chatbots
                    <ExternalLink className="h-4 w-4 ml-1 opacity-0 group-hover:opacity-100 transition-opacity" />
                  </Link>
                </li>
              </ul>
            </div>
            
            <div>
              <h3 className="text-white font-semibold mb-4" id="company-heading">Company</h3>
              <ul className="space-y-3" aria-labelledby="company-heading">
                <li>
                  <button onClick={() => document.getElementById('how-it-works')?.scrollIntoView({ behavior: 'smooth' })} className="text-gray-400 hover:text-blue-400 transition-colors">
                    How It Works
                  </button>
                </li>
                <li>
                  <button onClick={() => document.getElementById('benefits')?.scrollIntoView({ behavior: 'smooth' })} className="text-gray-400 hover:text-blue-400 transition-colors">
                    Benefits
                  </button>
                </li>
              </ul>
            </div>
          </div>
          
          <div className="pt-8 border-t border-gray-800">
            <p className="text-gray-500 text-sm text-center">
              © {new Date().getFullYear()} ZenTalk. All rights reserved.
            </p>
          </div>
        </div>
      </div>
    </footer>
  );
};

export default Footer;